Name:           stunnel
Version:        5.72
Release:        2
Summary:        Secure traffic running between a TCP client and server
License:        GPLv2
URL:            http://www.stunnel.org/
Source0:        https://www.usenix.org.uk/mirrors/stunnel/archive/5.x/%{name}-%{version}.tar.gz
Source1:        https://www.usenix.org.uk/mirrors/stunnel/archive/5.x/%{name}-%{version}.tar.gz.asc
Source2:        stunnel@.service

BuildRequires:  pkgconfig util-linux autoconf automake libtool compat-openssl11-devel
BuildRequires:  perl-podlators perl nmap-ncat lsof procps-ng systemd
%{?systemd_requires}

%description
The stunnel program is designed to work as SSL encryption
wrapper between remote clients and local (inetd-startable)
or remote servers. The concept is that having non-SSL
aware daemons running on your system you can easily set
them up to communicate with clients over secure SSL chan-
nels.

stunnel can be used to add SSL functionality to commonly
used inetd daemons like POP-2, POP-3, and IMAP servers, to
standalone daemons like NNTP, SMTP and HTTP, and in tun-
neling PPP over network sockets without changes to the
source code.

%package        help
Summary:        This package contains help documents
Requires:       %{name} = %{version}-%{release}
Buildarch:      noarch

%description    help
Files for help with stunnel.

%prep
%autosetup -n %{name}-%{version} -p1
change_date=`date +%Y.%m.%d`
sed -i "s/2024\.02\.04/${change_date}/g" `grep "2024\.02\.04" -lr ./`
sed -i 's/-fstack-protector/-fstack-protector-strong/' configure

%build
CFLAGS="$RPM_OPT_FLAGS -fPIC `pkg-config --cflags openssl`"; export CFLAGS
LDFLAGS="`pkg-config --libs-only-L openssl`"; export LDFLAGS
%configure --enable-fips --enable-ipv6 --with-ssl=%{_prefix} --disable-libwrap \
        CPPFLAGS="-UPIDFILE -DPIDFILE='\"%{_localstatedir}/run/stunnel.pid\"'"
make V=1 LDADD="-pie -Wl,-z,defs,-z,relro,-z,now"

%install
%make_install
for lang in pl ; do
        install -d %{buildroot}/%{_mandir}/${lang}/man8
        mv %{buildroot}/%{_mandir}/man8/*.${lang}.8* %{buildroot}/%{_mandir}/${lang}/man8/
        rename ".${lang}" "" %{buildroot}/%{_mandir}/${lang}/man8/*
done
install -D %{buildroot}%{_datadir}/doc/stunnel/examples/%{name}.service %{buildroot}%{_unitdir}/%{name}.service
install -D %{SOURCE2} %{buildroot}%{_unitdir}/%{name}@.service

%post
/sbin/ldconfig
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
/sbin/ldconfig
%systemd_postun_with_restart %{name}.service

%files
%license COPY*
%doc AUTHORS.md BUGS.md CREDITS.md PORTS.md README.md TODO.md
%{_bindir}/stunnel
%exclude %{_bindir}/stunnel3
%{_libdir}/stunnel
%exclude %{_libdir}/stunnel/libstunnel.la
%dir %{_sysconfdir}/%{name}
%exclude %{_sysconfdir}/stunnel/*
%{_unitdir}/%{name}*.service

%files help
%{_mandir}/man8/stunnel.8*
%doc tools/stunnel.conf-sample
%lang(en) %doc doc/en/*
%lang(pl) %doc doc/pl/*
%lang(pl) %{_mandir}/pl/man8/stunnel.8*
%exclude %{_datadir}/doc/stunnel

%changelog
* Wed Aug 21 2024 Jiuwang He <hejiuwang@cqsoftware.com.cn> - 5.72-2
- Add Buildarch: noarch to the help subpackage

* Thu Jul 04 2024 Ge Wang <wang__ge@126.com> - 5.72-1
- Update to 5.72

* Wed Apr 19 2023 yaoxin <yao_xin001@hoperun.com> - 5.69-1
- Update to 5.69

* Tue Feb 07 2023 wulei <wulei80@h-partners.com> - 5.48-5
- Fix undefined reference to 'FIPS_mode'

* Thu Sep 10 2020 baizhonggui<baizhonggui@huawei.com> - 5.48-4
- Modify source0

* Sun Jan 19 2020 duyeyu<duyeyu@huawei.com> - 5.48-3
- delete conf file and patch 

* Mon Nov 25 2019 gulining<gulining1@huawei.com> - 5.48-2
- Pakcage init
